PyNSN
=====

**Creating Non-Symbolic Number Displays**

---


*Released under the GNU General Public License v3* 

Oliver Lindemann (lindemann@cognitive-psychology.eu)

Project homepage: https://github.com/lindemann09/PyNSN


Dependencies
------------

* Python 3 (>=3.5)
* PyQT5 
* numpy (>=1.6)
* scipy (>=1.0)
* pillow (>=5.0)
* svgwrite>=1.4
* pandas>=1.3

Additional Python packages, which are optional and required only for some 
features:

* pygame (>=1.9)
* expyriment (>=0.8)

Installing via `pip`
--------------------

```
python3 -m pip install pynsn
```

To generate [Pygame](https://www.pygame.org/news) or [Expyriment](http://expyriment.org) stimuli, please install the
respective packages.



RUN GUI tool
-------------

Note: Using the PyNSN-GUI requires the installation of `PyQt5` 

```
python3 -m pynsn
```

or if installed correctly:

```
pynsn
```


